"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.boolExpToSQL = exports.applyBoolExpToLink = exports.userPublicSymbol = exports.itemPublicSymbol = exports.userReplaceSymbol = exports.itemReplaceSymbol = exports.api = void 0;
const debug_1 = __importDefault(require("debug"));
const client_1 = require("@deep-foundation/hasura/client");
const api_1 = require("@deep-foundation/hasura/api");
const client_2 = require("./client");
const debug = (0, debug_1.default)('deeplinks:bool_exp');
const log = debug.extend('log');
const error = debug.extend('error');
const namespaces = debug_1.default.disable();
debug_1.default.enable(`${namespaces ? `${namespaces},` : ``}${error.namespace}`);
exports.api = new api_1.HasuraApi({
    path: process.env.DEEPLINKS_HASURA_PATH,
    ssl: !!+process.env.DEEPLINKS_HASURA_SSL,
    secret: process.env.DEEPLINKS_HASURA_SECRET,
});
const client = (0, client_1.generateApolloClient)({
    path: `${process.env.DEEPLINKS_HASURA_PATH}/v1/graphql`,
    ssl: !!+process.env.DEEPLINKS_HASURA_SSL,
    secret: process.env.DEEPLINKS_HASURA_SECRET,
});
const deep = new client_2.DeepClient({
    apolloClient: client,
});
exports.itemReplaceSymbol = 777777777777;
exports.userReplaceSymbol = 777777777778;
exports.itemPublicSymbol = 'X-Deep-Item-Id';
exports.userPublicSymbol = 'X-Deep-User-Id';
const applyBoolExpToLink = (sql, linkId) => {
    return sql.replace(`${exports.itemReplaceSymbol}`, `${linkId}`);
};
exports.applyBoolExpToLink = applyBoolExpToLink;
const boolExpToSQL = (boolExpId, boolExpValue) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b, _c;
    log('boolExpToSQL', boolExpId, boolExpValue);
    let gql, explained, sql;
    try {
        if (typeof (boolExpValue) !== 'object') {
            throw new Error('boolExpValue must be object');
        }
        const serializedQuery = deep.serializeQuery(boolExpValue);
        gql = JSON.stringify(serializedQuery === null || serializedQuery === void 0 ? void 0 : serializedQuery.where).replace(/"([^"]+)":/g, '$1:');
        gql = gql.replace(new RegExp(`'${exports.userPublicSymbol}'`, 'g'), exports.userReplaceSymbol);
        gql = gql.replace(new RegExp(`"${exports.userPublicSymbol}"`, 'g'), exports.userReplaceSymbol);
        gql = gql.replace(new RegExp(`'${exports.itemPublicSymbol}'`, 'g'), exports.itemReplaceSymbol);
        gql = gql.replace(new RegExp(`"${exports.itemPublicSymbol}"`, 'g'), exports.itemReplaceSymbol);
        explained = yield exports.api.explain(`{ links(where: { _and: [{ id: { _eq: ${exports.itemReplaceSymbol} } }, ${gql}] }, limit: 1) { id } }`);
        sql = (_b = (_a = explained === null || explained === void 0 ? void 0 : explained.data) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.sql;
        if (sql) {
            const convertedSql = `SELECT json_array_length("root") as "root" FROM (${sql}) as "root"`;
            const boolExp = yield deep.select({ link_id: { _eq: boolExpId } }, { table: 'bool_exp', returning: 'id link_id' });
            const boolExpLink = (_c = boolExp === null || boolExp === void 0 ? void 0 : boolExp.data) === null || _c === void 0 ? void 0 : _c[0];
            log('boolExpLink', boolExpLink);
            if (boolExpLink) {
                const mutateResult = yield deep.update(boolExpLink.id, {
                    value: convertedSql,
                }, { table: 'bool_exp' });
            }
            else {
                const mutateResult = yield deep.insert({
                    link_id: boolExpId,
                    value: convertedSql,
                }, { table: 'bool_exp' });
            }
        }
    }
    catch (e) {
        error(e);
        error('error', gql, explained, sql);
    }
});
exports.boolExpToSQL = boolExpToSQL;
//# sourceMappingURL=bool_exp_to_sql.js.map